@@ -19,6 +19,7 @@ import (
 	"html/template"
 
 	"github.com/gohugoio/hugo/identity"
+	"github.com/gohugoio/hugo/markup/converter"
 
 	"github.com/bep/gitmap"
 	"github.com/gohugoio/hugo/config"
@@ -105,6 +106,11 @@ type ContentProvider interface {
 	Len() int
 }
 
+// ContentRenderer provides the content rendering methods for some content.
+type ContentRenderer interface {
+	RenderContent(content []byte, renderTOC bool) (converter.Result, error)
+}
+
 // FileProvider provides the source file.
 type FileProvider interface {
 	File() source.File
